local mod = ...


-- Assets -------------------------------------------------------------------------------------
mod:registerAssetId("models/Creamery1.fbx/Prefab/CreameryPart", "PREFAB_ORCHARD_CREAMERY1")



-- Construction visual
mod:registerAssetId("models/Creamery1.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_ORCHARD_CREAMERY1")



-- Grounding  -------------------------------------------------------------------------------------
mod:registerPrefabComponent("models/Creamery1.fbx/Prefab/CreameryPart/Table.001", {DataType = "COMP_GROUNDED"})

for i=1, 8, 1 do
	mod:registerPrefabComponent("models/Creamery1.fbx/Prefab/CreameryPart/Barrel." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
end



-- Building Asset Processor  -------------------------------------------------------------------------------------
mod:registerAssetProcessor("models/Creamery1.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Particle (Smoke) -------------------------------------------------------------------------------------

mod:registerAssetId("models/Creamery1.fbx/Prefab/CreameryPart/SmokeEmitter.001", "PREFAB_ORCHARD_CREAMERY_SMOKE_EMITTER")

mod:registerPrefabComponent("models/Creamery1.fbx/Prefab/CreameryPart/SmokeEmitter.001", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "AIR_VENT_PARTICLE_SYSTEM",
	IsPlaying = true,
	IsEmitting = true
})

mod:registerPrefabComponent("models/Creamery1.fbx/Prefab/CreameryPart/SmokeEmitter.001", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})

mod:registerPrefabComponent("models/Creamery1.fbx/Prefab/CreameryPart/SmokeEmitter.001", { 
	DataType = "COMP_BUILDING_PART", 
	FeedbackComponentListToActivate = {
		{ "PREFAB_ORCHARD_CREAMERY_SMOKE_EMITTER", "COMP_PARTICLE_EMITTER_TOGGLE" }
	}
})



-- Resource -------------------------------------------------------------------------------------

mod:registerAssetId("icons/Butter.png", "ICON_BUTTER")

mod:register({
	DataType = "RESOURCE",
	Id = "BV1_BUTTER",
	ResourceName = "BV1_BUTTER_NAME",
	Icon = "ICON_BUTTER",
	ResourceTypeList = { "RESOURCE_FOOD" },
	IsTradable = true,
	ResourceLayoutType = "CRATES",
	-- VillagerBuyingPrice = { Resource = "GOLD", Quantity = 2 },
	DisplayInInventory = true
})



-- Job -------------------------------------------------------------------------------------

mod:register({
	DataType = "JOB",
	Id = "JOB_ORCHARD_CREAMERY",
	JobName = "JOB_ORCHARD_CREAMERY_NAME",
	JobDescription = "JOB_ORCHARD_CREAMERY_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 60.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
        -- FemaleHatList = {
        --     "PREFAB_HAT_FARMER3",
        -- }, 
        -- MaleHatList = {
        --     "PREFAB_HAT_FARMER3",
        -- }, 
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_ORCHARD_CREAMERY"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_ORCHARD_CREAMERY"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_ORCHARD_CREAMERY"
    }
})



-- Building Function: Creamery -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "BUILDING_FUNCTION_ORCHARD_CREAMERY",
    Name = "BUILDING_FUNCTION_ORCHARD_CREAMERY_NAME",
    WorkerCapacity = 2,
    RelatedJob = { 
        Job = "JOB_ORCHARD_CREAMERY", 
        Behavior = "BEHAVIOR_WORK"
    },
    InputInventoryCapacity = {
		{ Resource = "MILK", Quantity = 50 },
	},
    ResourceListNeeded = {
		{ Resource = "MILK", Quantity = 3 }, 
	},
	ResourceProduced = {
        { Resource = "BV1_BUTTER", Quantity = 1 },
    }
})



-- Building: Creamery -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING",
	Id = "BUILDING_ORCHARD_CREAMERY",
	Name = "BUILDING_ORCHARD_CREAMERY_NAME",
	Description = "BUILDING_ORCHARD_CREAMERY_DESC",
    BuildingType = "GENERAL",
    AssetCoreBuildingPart = "BUILDING_PART_MONUMENT_POLE", 
    BuildingPartSetList = {
        {
            Name = "BUILDING_PART_SET_ORCHARD_CREAMERY1",
            BuildingPartList = { 
                "BUILDING_PART_ORCHARD_CREAMERY1",
            }
        },
    },	
    RequiredPartList = {
        { Category = "CORE", Quantity = 1 }, 
    },
    IsEditable = true,
	-- VillagerRequired = { Status = "CITIZEN", Quantity = 1 },
})



-- Building part: Creamery 1 -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
    Id = "BUILDING_PART_ORCHARD_CREAMERY1",
    Name = "BUILDING_PART_ORCHARD_CREAMERY1_NAME",
    Category = "CORE", 
    AssetBuildingFunction = "BUILDING_FUNCTION_ORCHARD_CREAMERY",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {8.0, 8.0}, {0.15, 0.0}),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = false } 
            },
            { 
                Polygon = polygon.createRectangle( {2, 2}, {1.5, 4.0}),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = false } 
            },
		}
	},
    ConstructorData = {
        DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
        CoreObjectPrefab = "PREFAB_ORCHARD_CREAMERY1"
    }, 
    ConstructionVisual = "PREFAB_CONSTR_ORCHARD_CREAMERY1", 
    Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 25 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 20 } },
		RessourcesNeeded = {
            { Resource = "STONE", Quantity = 15 },
            { Resource = "WOOD", Quantity = 5 },
            { Resource = "PLANK", Quantity = 5 },
		}
    }
})
